@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2020 Tada AB and other contributors, as listed below.
+ * Copyright (c) 2018-2021 Tada AB and other contributors, as listed below.
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the The BSD 3-Clause License
@@ -73,6 +73,10 @@ do { \
 #define _VL_TYPE struct varlena *
 #endif
 
+#if PG_VERSION_NUM < 140000
+#define VARATT_EXTERNAL_GET_EXTSIZE(toast_pointer) ((toast_pointer).va_extsize)
+#endif
+
 #define INITIALSIZE 1024
 
 static jclass s_VarlenaWrapper_class;
@@ -219,7 +223,7 @@ jobject pljava_VarlenaWrapper_Input(
 			 */
 			struct varatt_external toast_pointer;
 			VARATT_EXTERNAL_GET_POINTER(toast_pointer, vl);
-			parked = toast_pointer.va_extsize + VARHDRSZ;
+			parked = VARATT_EXTERNAL_GET_EXTSIZE(toast_pointer) + VARHDRSZ;
 			if ( (actual >> 1) < parked ) /* not compressed enough to bother */
 				goto justDetoastEagerly;
 			vl = detoast_external_attr(vl); /* fetch without decompressing */
@@ -520,7 +524,7 @@ Java_org_postgresql_pljava_internal_VarlenaWrapper_00024Input_00024State__1detoa
 	Ptr2Long p2ldetoasted;
 	_VL_TYPE detoasted;
 	MemoryContext prevcxt;
-	jobject dbb;
+	jobject dbb = NULL;
 
 	BEGIN_NATIVE_NO_ERRCHECK
 
@@ -577,18 +581,18 @@ JNIEXPORT jlong JNICALL Java_org_postgresql_pljava_internal_VarlenaWrapper_00024
 	MemoryContext prevcxt;
 	_VL_TYPE fetched;
 
-	BEGIN_NATIVE_NO_ERRCHECK;
 	p2lvl.longVal = varlena;
 	p2lcxt.longVal = memContext;
 
+	BEGIN_NATIVE_NO_ERRCHECK;
 	prevcxt = MemoryContextSwitchTo((MemoryContext) p2lcxt.ptrVal);
 	fetched = detoast_external_attr((_VL_TYPE) p2lvl.ptrVal);
 	pfree(p2lvl.ptrVal);
 	p2lvl.longVal = 0L;
 	p2lvl.ptrVal = fetched;
 	MemoryContextSwitchTo(prevcxt);
-
 	END_NATIVE;
+
 	return p2lvl.longVal;
 }
 
@@ -606,7 +610,7 @@ Java_org_postgresql_pljava_internal_VarlenaWrapper_00024Output_00024State__1next
 	ExpandedVarlenaOutputStreamNode *node;
 	Ptr2Long p2l;
 	Datum d;
-	jobject dbb;
+	jobject dbb = NULL;
 
 	p2l.longVal = varlenaPtr;
 	d = PointerGetDatum(p2l.ptrVal);
