@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018 Tada AB and other contributors, as listed below.
+ * Copyright (c) 2018-2019 Tada AB and other contributors, as listed below.
  *
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the The BSD 3-Clause License
@@ -27,6 +27,10 @@ extern void pljava_DualState_cleanEnqueuedInstances(void);
 
 extern void pljava_DualState_initialize(void);
 
+extern void pljava_DualState_unregister(void);
+
+extern void pljava_DualState_nativeRelease(void *);
+
 #ifdef __cplusplus
 }
 #endif
